<?php

namespace Drupal\route_in_modal;

use Drupal\Core\Config\ConfigFactoryInterface;

/**
 * A helper class for managing configured routes.
 */
class ModalRouteHelper {

  /**
   * The module config.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $config;

  /**
   * Constructs a ModalRouteHelper object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory service.
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    $this->config = $config_factory->get('route_in_modal.settings');
  }

  /**
   * Returns the configured routes.
   *
   * @return array
   *   The configured routes as array.
   */
  public function getRoutes(): array {
    $routes = $this->config->get('routes');

    return (empty($routes) ? [] : explode("\r\n", $routes));
  }

  /**
   * Check if route is configured to open in modal.
   *
   * @param string $route
   *   The route to check.
   *
   * @return bool
   *   True if route is configured to open in modal, false otherwise.
   */
  public function routeHasModal(string $route): bool {
    return in_array($route, $this->getRoutes(), TRUE);
  }

}
